@@ -5,4 +5,6 @@ from quickai import *
 from .image_classification import ImageClassification, ImageClassificationPredictor
 from .text_inferance import gpt_neo, q_and_a, sentiment_analysis, ner, summarization, classification_ft
 from .text_finetuning import TextFineTuning
-from .yolo.detect import YOLOV4
\ No newline at end of file
+from .yolo.train import YOLOV4_Train
+from .yolo.detect import YOLOV4
+from .yolo.detect_custom import YOLOV4_Custom
